@@ -1,6 +1,9 @@
 # -*- coding: utf-8 -*-
-import re
+from __future__ import unicode_literals
+
 import os
+
+
 extensions = [
     'sphinx.ext.autodoc',
     'sphinx.ext.autosummary',
@@ -17,16 +20,17 @@ if os.getenv('SPELLCHECK'):
 
 source_suffix = '.rst'
 master_doc = 'index'
-project = u'python-fields'
-copyright = u'2014, Ionel Cristian Mărieș'
-version = release = re.findall(
-    'version="(.*)"',
-    open(os.path.join(os.path.dirname(__file__), '../setup.py')).read()
-)[0]
-
+project = 'Fields'
+year = '2014-2015'
+author = 'Ionel Cristian Mărieș'
+copyright = '{0}, {1}'.format(year, author)
+version = release = '5.0.0'
 import sphinx_py3doc_enhanced_theme
 html_theme = "sphinx_py3doc_enhanced_theme"
 html_theme_path = [sphinx_py3doc_enhanced_theme.get_html_theme_path()]
+html_theme_options = {
+    'githuburl': 'https://github.com/ionelmc/python-fields/'
+}
 
 pygments_style = 'trac'
 templates_path = ['.']
@@ -37,6 +41,3 @@ html_sidebars = {
    '**': ['searchbox.html', 'globaltoc.html', 'sourcelink.html'],
 }
 html_short_title = '%s-%s' % (project, version)
-html_theme_options = {
-    'githuburl': 'https://github.com/ionelmc/python-fields/'
-}
\ No newline at end of file
